@@ -17,25 +17,25 @@ sub pointer {
 sub load_dynamic_libs {
   my ($self) = @_;
 
-  my $module_names = $self->get_module_names;
+  my $basic_type_names = $self->get_module_names;
 
   # Set addresses of native methods
-  for my $module_name (@$module_names) {
+  for my $basic_type_name (@$basic_type_names) {
     my $category = 'native';
-    my $method_names = $self->get_method_names($module_name, $category);
+    my $method_names = $self->get_method_names($basic_type_name, $category);
     
     if (@$method_names) {
       # Build classs - Compile C source codes and link them to SPVM precompile method
       # Shared library which is already installed in distribution directory
-      my $module_file = $self->get_module_file($module_name);
+      my $module_file = $self->get_module_file($basic_type_name);
       my $dynamic_lib_file = SPVM::Builder::Util::get_dynamic_lib_file_dist($module_file, $category);
       
       if (-f $dynamic_lib_file) {
-        my $method_addresses = SPVM::Builder::Util::get_method_addresses($dynamic_lib_file, $module_name, $method_names, [], $category);
+        my $method_addresses = SPVM::Builder::Util::get_method_addresses($dynamic_lib_file, $basic_type_name, $method_names, $category);
         
         for my $method_name (sort keys %$method_addresses) {
           my $cfunc_address = $method_addresses->{$method_name};
-          $self->set_native_method_address($module_name, $method_name, $cfunc_address);
+          $self->set_native_method_address($basic_type_name, $method_name, $cfunc_address);
         }
       }
     }
@@ -45,9 +45,9 @@ sub load_dynamic_libs {
 sub get_module_names {
   my ($self) = @_;
   
-  my $module_names = $self->get_basic_type_names;
+  my $basic_type_names = $self->get_basic_type_names;
   
-  return $module_names;
+  return $basic_type_names;
 }
 
 1;
