@@ -9,7 +9,7 @@
 #include <string.h>
 #include <stdarg.h>
 
-#define SPVM_NATIVE_VERSION_NUMBER 0.989024
+#define SPVM_NATIVE_VERSION_NUMBER 0.989025
 
 #define SPVM_NATIVE_CREATE_VERSION_STRING_STRINGIFY(x) #x
 
@@ -408,6 +408,7 @@ struct spvm_api_basic_type {
 
 struct spvm_api_class_var {
   const char* (*get_name)(void* runtime, void* class_var);
+  int32_t (*get_index)(void* runtime, void* class_var);
   void* (*get_basic_type)(void* runtime, void* class_var);
   int32_t (*get_type_dimension)(void* runtime, void* class_var);
   int32_t (*get_type_flag)(void* runtime, void* class_var);
@@ -457,6 +458,8 @@ struct spvm_api_method {
 };
 
 struct spvm_api_arg {
+  const void* (*get_name)(void* runtime, void* arg);
+  int32_t (*get_index)(void* runtime, void* arg);
   void* (*get_basic_type)(void* runtime, void* arg);
   int32_t (*get_type_dimension)(void* runtime, void* arg);
   int32_t (*get_type_flag)(void* runtime, void* arg);
