@@ -10,7 +10,7 @@
 struct spvm_runtime {
   SPVM_ALLOCATOR* allocator;
   
-  SPVM_RUNTIME_BASIC_TYPE* basic_types;
+  SPVM_RUNTIME_BASIC_TYPE** basic_types;
   
   SPVM_HASH* basic_type_symtable;
   
@@ -19,6 +19,8 @@ struct spvm_runtime {
 
 SPVM_RUNTIME* SPVM_RUNTIME_new();
 
+SPVM_COMPILER* SPVM_COMPILER_new_with_runtime(SPVM_RUNTIME* runtime);
+
 void SPVM_RUNTIME_free(SPVM_RUNTIME* runtime);
 
 #endif
