@@ -36,7 +36,7 @@ SPVM_API_COMPILER* SPVM_API_COMPILER_new_api() {
     SPVM_API_COMPILER_clear_include_dirs,
     SPVM_API_COMPILER_get_module_file,
     SPVM_API_COMPILER_add_module_file,
-    SPVM_API_COMPILER_build_runtime,
+    SPVM_API_COMPILER_get_runtime,
   };
   SPVM_API_COMPILER* env_compiler = calloc(1, sizeof(env_compiler_init));
   memcpy(env_compiler, env_compiler_init, sizeof(env_compiler_init));
@@ -116,9 +116,9 @@ const char* SPVM_API_COMPILER_get_error_message(SPVM_COMPILER* compiler, int32_t
   return SPVM_COMPILER_get_error_message(compiler, index);
 }
 
-SPVM_RUNTIME* SPVM_API_COMPILER_build_runtime(SPVM_COMPILER* compiler) {
+SPVM_RUNTIME* SPVM_API_COMPILER_get_runtime(SPVM_COMPILER* compiler) {
   
-  SPVM_RUNTIME* runtime = SPVM_COMPILER_build_runtime(compiler);
+  SPVM_RUNTIME* runtime = SPVM_COMPILER_get_runtime(compiler);
   
   return runtime;
 }
