@@ -251,16 +251,16 @@ int32_t SPVM_BASIC_TYPE_is_super_class(SPVM_COMPILER* compiler, int32_t super_ba
   SPVM_BASIC_TYPE* super_basic_type = SPVM_LIST_get(compiler->basic_types, super_basic_type_id);
   SPVM_BASIC_TYPE* child_basic_type = SPVM_LIST_get(compiler->basic_types, child_basic_type_id);
   
-  const char* cur_parent_basic_type_name = child_basic_type->parent_name;
+  const char* current_parent_basic_type_name = child_basic_type->parent_name;
   while (1) {
-    if (cur_parent_basic_type_name) {
-      if (strcmp(super_basic_type->name, cur_parent_basic_type_name) == 0) {
+    if (current_parent_basic_type_name) {
+      if (strcmp(super_basic_type->name, current_parent_basic_type_name) == 0) {
         return 1;
       }
       else {
-        SPVM_BASIC_TYPE* cur_parent_basic_type = SPVM_HASH_get(compiler->basic_type_symtable, cur_parent_basic_type_name, strlen(cur_parent_basic_type_name));
-        assert(cur_parent_basic_type);
-        cur_parent_basic_type_name = cur_parent_basic_type->parent_name;
+        SPVM_BASIC_TYPE* current_parent_basic_type = SPVM_HASH_get(compiler->basic_type_symtable, current_parent_basic_type_name, strlen(current_parent_basic_type_name));
+        assert(current_parent_basic_type);
+        current_parent_basic_type_name = current_parent_basic_type->parent_name;
       }
     }
     else {
